package com.boman.file.service;

import com.alibaba.fastjson.JSONObject;
import com.boman.common.core.utils.SpringUtils;
import com.boman.common.core.utils.obj.ObjectUtils;
import com.boman.common.core.utils.poi.ExcelUtil;
import com.boman.common.core.web.domain.AjaxResult;
import com.boman.common.redis.RedisKey;
import com.boman.common.redis.service.RedisService;
import com.boman.domain.GenTable;
import com.boman.domain.GenTableColumn;
import com.boman.domain.dto.ImportExcelDto;
import com.boman.file.utils.FileUploadUtils;
import com.boman.web.core.api.RemoteObjService;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.cloud.context.config.annotation.RefreshScope;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.List;
import java.util.Objects;

/**
 * 本地文件存储
 * 
 * @author ruoyi
 */
@Primary
@Service
@RefreshScope
public class LocalSysFileServiceImpl implements ISysFileService
{

    @Resource
    private RemoteObjService remoteObjService;
    @Resource
    private RedisService redisService;

    /**
     * 资源映射路径 前缀
     */
    @Value("${file.prefix}")
    public String localFilePrefix;

    /**
     * 域名或本机访问地址
     */
    @Value("${file.domain}")
    public String domain;
    
    /**
     * 上传文件存储在本地的根路径
     */
    @Value("${file.path}")
    private String localFilePath;

    /**
     * 本地文件上传接口
     * 
     * @param file 上传的文件
     * @return 访问地址
     * @throws Exception
     */
    @Override
    public String uploadFile(MultipartFile file) throws Exception
    {
        String name = FileUploadUtils.upload(localFilePath, file);
        String url = domain + localFilePrefix + name;
        return url;
    }

    /**
     * 功能描述: 上传base64
     *
     * @param base64 base64
     * @return java.lang.String
     */
    @Override
    public String uploadFileBase64(String base64) throws IOException {
        MultipartFile multipartFile = FileUploadUtils.base64ToMultipart(base64);
        String name = FileUploadUtils.upload(localFilePath, multipartFile);
        return domain + localFilePrefix + name;
    }

    /**
     * 功能描述: 通用的导入接口
     *
     * @param multipartFile multipartFile
     * @param tableName     tableName
     * @return java.util.List<com.alibaba.fastjson.JSONObject>
     */
    @Override
    public AjaxResult importExcelCommon(MultipartFile multipartFile, String tableName) throws Exception {
        Objects.requireNonNull(multipartFile, "multipartFile is empty");
        ObjectUtils.requireNonNull(tableName, "tableName is empty");

        GenTable genTable = redisService.getCacheObject(RedisKey.TABLE_INFO + tableName);
        List<GenTableColumn> columns = genTable.getColumns();

        ExcelUtil<JSONObject> util = new ExcelUtil<>(JSONObject.class);
        List<JSONObject> list = util.importCommonExcel("", multipartFile.getInputStream(), columns);

        ImportExcelDto dto = new ImportExcelDto();
        dto.setDataList(list);
        dto.setTableName(tableName);

        return remoteObjService.importCommonData(dto);
    }

    /**f
     * 功能描述: 通用的导入接口
     *
     * @param dto@return java.util.List<com.alibaba.fastjson.JSONObject>
     */
    @Override
    public List<JSONObject> importExcelCommon(ImportExcelDto dto) throws Exception {
        return null;
    }
}
