package com.boman.system.controller;

import java.util.List;

import com.boman.common.core.utils.poi.ExcelUtil;
import com.boman.common.core.web.controller.BaseController;
import com.boman.common.core.web.domain.AjaxResult;
import com.boman.common.core.web.page.TableDataInfo;
import com.boman.common.log.annotation.Log;
import com.boman.common.log.enums.BusinessType;
import com.boman.common.security.annotation.PreAuthorize;
import com.boman.system.domain.AttendanceSet;
import com.boman.system.service.IAttendanceSetService;
import org.gavaghan.geodesy.GlobalCoordinates;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;


/**
 * 考勤设置Controller
 * 
 * @author ruoyi
 * @date 2021-06-04
 */
@RestController
@RequestMapping("/attendance/set")
public class AttendanceSetController extends BaseController
{
    @Autowired
    private IAttendanceSetService attendanceSetService;

    /**
     * 查询考勤设置列表
     */
    @GetMapping("/list")
    public TableDataInfo list(AttendanceSet attendanceSet)
    {
        startPage();
        List<AttendanceSet> list = attendanceSetService.selectAttendanceSetList(attendanceSet);
        return getDataTable(list);
    }


    /**
     * 获取考勤设置详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(attendanceSetService.selectAttendanceSetById(id));
    }

    /**
     * 新增考勤设置
     */
    @Log(title = "考勤设置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AttendanceSet attendanceSet)
    {
        return toAjax(attendanceSetService.insertAttendanceSet(attendanceSet));
    }

    /**
     * 修改考勤设置
     */
    @Log(title = "考勤设置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AttendanceSet attendanceSet)
    {
        return toAjax(attendanceSetService.updateAttendanceSet(attendanceSet));
    }

    /**
     * 删除考勤设置
     */
    @Log(title = "考勤设置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(attendanceSetService.deleteAttendanceSetByIds(ids));
    }


    /**
     * 功能描述: 根据传入的经纬度计算是否在设置的范围之内
     *
     * @param globalCoordinates 经纬度对象
     * @return com.boman.common.core.web.domain.AjaxResult
     */
    @PostMapping("/distanceMeter")
    public AjaxResult getDistanceMeter(@RequestBody GlobalCoordinates globalCoordinates) {
        return AjaxResult.success(attendanceSetService.getDistanceMeter(globalCoordinates));
    }
}
